#!/usr/bin/env python

from distutils.core import setup

setup(name='Seki-C-syntax-highlighter',
      version='1.0',
      description='syntax highlighter university project',
      author='Sebastian Kisela',
      author_email='seki98@gmail.com',
      url='https://github.com/seki98/school.git/2roc/IPP/proj2',
      #packages=[''],
     )
